@@ -97,8 +97,13 @@
 	# to be caught when using the substr function
 	if(modelinc[2]>0){
 		arnames=paste("ar",1:modelinc[2],sep="")
-		pars[idx["ar", 1]:idx["ar", 2], 5] = -1+TinY
-		pars[idx["ar", 1]:idx["ar", 2], 6] =  1-TinY
+		if(modelinc[2]==1){
+			pars[idx["ar", 1]:idx["ar", 2], 5] = -1+TinY
+			pars[idx["ar", 1]:idx["ar", 2], 6] =  1-TinY
+		} else{
+			pars[idx["ar", 1]:idx["ar", 2], 5] = -4+TinY
+			pars[idx["ar", 1]:idx["ar", 2], 6] =  4-TinY
+		}
 		for(i in 1:modelinc[2]){
 			if(i<10) ix = 3 else ix = 4
 			if(any(substr(start.names, 1, ix)==paste("ar", i, sep = ""))){
@@ -121,8 +126,13 @@
 	# ma
 	if(modelinc[3]>0){
 		manames = paste("ma",1:modelinc[3],sep="")
-		pars[idx["ma", 1]:idx["ma", 2], 5] = -1+TinY
-		pars[idx["ma", 1]:idx["ma", 2], 6] =  1-TinY
+		if(modelinc[3]==1){
+			pars[idx["ma", 1]:idx["ma", 2], 5] = -1+TinY
+			pars[idx["ma", 1]:idx["ma", 2], 6] =  1-TinY
+		} else{
+			pars[idx["ma", 1]:idx["ma", 2], 5] = -4+TinY
+			pars[idx["ma", 1]:idx["ma", 2], 6] =  4-TinY
+		}
 		if(any(substr(start.names, 1, 2)=="ma")){
 			j = which(substr(start.names, 1, 2)=="ma")
 			mamatch = charmatch(start.names[j],manames)
@@ -383,8 +393,14 @@
 	# to be caught when using the substr function
 	if(modelinc[2]>0){
 		arnames=paste("ar",1:modelinc[2],sep="")
-		pars[idx["ar", 1]:idx["ar", 2], 5] = -1+TinY
-		pars[idx["ar", 1]:idx["ar", 2], 6] =  1-TinY
+		# ar1 stationarity bounds else...
+		if(modelinc[2]==1){
+			pars[idx["ar", 1]:idx["ar", 2], 5] = -1+TinY
+			pars[idx["ar", 1]:idx["ar", 2], 6] =  1-TinY
+		} else{
+			pars[idx["ar", 1]:idx["ar", 2], 5] = -4+TinY
+			pars[idx["ar", 1]:idx["ar", 2], 6] =  4-TinY
+		}
 		for(i in 1:modelinc[2]){
 			if(i<10) ix = 3 else ix = 4
 				if(any(substr(start.names, 1, ix)==paste("ar", i, sep = ""))){
@@ -407,8 +423,13 @@
 	# ma
 	if(modelinc[3]>0){
 		manames = paste("ma",1:modelinc[3],sep="")
-		pars[idx["ma", 1]:idx["ma", 2], 5] = -1+TinY
-		pars[idx["ma", 1]:idx["ma", 2], 6] =  1-TinY
+		if(modelinc[3]==1){
+			pars[idx["ma", 1]:idx["ma", 2], 5] = -1+TinY
+			pars[idx["ma", 1]:idx["ma", 2], 6] =  1-TinY
+		} else{
+			pars[idx["ma", 1]:idx["ma", 2], 5] = -4+TinY
+			pars[idx["ma", 1]:idx["ma", 2], 6] =  4-TinY
+		}
 		if(any(substr(start.names, 1, 2)=="ma")){
 			j = which(substr(start.names, 1, 2)=="ma")
 			mamatch = charmatch(start.names[j],manames)
@@ -478,7 +499,8 @@
 			gjrGARCH = .gjrgarchstart(pars, data, garchenv),
 			apARCH = .aparchstart(pars, data, garchenv),
 			eGARCH = .egarchstart(pars, data, garchenv),
-			iGARCH = .igarchstart(pars, data, garchenv))
+			iGARCH = .igarchstart(pars, data, garchenv),
+			hyGARCH = .hygarchstart(pars, data, garchenv))
 	#anstGARCH = .anstgarchstart(data, model, submodel, garchenv))
 	return(ans)
 }
@@ -597,7 +619,135 @@
 }
 
 
-
+.hygarchstart = function(pars, data, garchenv)
+{
+	model = get("model", garchenv)
+	dscale = get("dscale", garchenv)
+	modelinc = model$modelinc
+	start.pars = model$start.pars
+	fixed.pars = model$fixed.pars
+	idx = model$pidx
+	fixed.names = names(fixed.pars)
+	start.names = names(start.pars)
+	pars = .meqstart(pars, data, garchenv)
+	if(modelinc[7]>0){
+		pars[idx["omega", 1]:idx["omega", 2], 5] = var(data)/100000
+		pars[idx["omega", 1]:idx["omega", 2], 6] = var(data)*100000
+		if(is.null(start.pars$omega)) pars[idx["omega", 1]:idx["omega", 2], 1] = (var(data, na.rm = TRUE))/1000 else 
+			pars[idx["omega", 1]:idx["omega", 2], 1] = start.pars$omega[1]/dscale
+		if(any(substr(fixed.names, 1, 5) == "omega")){
+			pars[idx["omega", 1]:idx["omega", 2], 1] = as.numeric(fixed.pars$omega)
+			pars[idx["omega", 1]:idx["omega", 2], 5] = fixed.pars$omega
+			pars[idx["omega", 1]:idx["omega", 2], 6] = fixed.pars$omega
+		}
+	}
+	if(modelinc[8]>0){
+		gpnames = paste("alpha",1:modelinc[8],sep="")
+		pars[idx["alpha", 1]:idx["alpha", 2], 5] = -5
+		pars[idx["alpha", 1]:idx["alpha", 2], 6] = 1-TinY
+		pars[idx["alpha", 1]:idx["alpha", 2], 1] = rep(0.05/modelinc[8], modelinc[8])
+		if(any(substr(start.names, 1, 5) == "alpha")){
+			j = which(substr(start.names, 1, 5) == "alpha")
+			gpmatch = charmatch(start.names[j],gpnames)
+			pars[gpnames[gpmatch], 1] = as.numeric(start.pars[j])
+		}
+		if(any(substr(fixed.names, 1, 5) == "alpha")){
+			j = which(substr(fixed.names, 1, 5) == "alpha")
+			gpmatch = charmatch(fixed.names[j],gpnames)
+			pars[gpnames[gpmatch], 1] = as.numeric(fixed.pars[j])
+			pars[gpnames[gpmatch], 5] = as.numeric(fixed.pars[j])
+			pars[gpnames[gpmatch], 6] = as.numeric(fixed.pars[j])
+		}
+	}
+	if(modelinc[9] > 0){
+		gqnames = paste("beta",1:modelinc[9],sep="")
+		pars[idx["beta", 1]:idx["beta", 2], 5] = -5
+		pars[idx["beta", 1]:idx["beta", 2], 6] = 1-TinY
+		pars[idx["beta", 1]:idx["beta", 2], 1] = rep(0.9/modelinc[9], modelinc[9])
+		if(any(substr(start.names, 1, 4) == "beta")){
+			j = which(substr(start.names, 1, 4) == "beta")
+			gqmatch = charmatch(start.names[j],gqnames)
+			pars[gqnames[gqmatch], 1] = as.numeric(start.pars[j])
+		}
+		if(any(substr(fixed.names, 1, 4) == "beta")){
+			j = which(substr(fixed.names, 1, 4) == "beta")
+			gqmatch = charmatch(fixed.names[j],gqnames)
+			pars[gqnames[gqmatch], 1] = as.numeric(fixed.pars[j])
+			pars[gqnames[gqmatch], 5] = as.numeric(fixed.pars[j])
+			pars[gqnames[gqmatch], 6] = as.numeric(fixed.pars[j])
+		}
+	}
+	if(modelinc[13]>0){
+		pars[idx["delta", 1]:idx["delta", 2], 5] = 0
+		pars[idx["delta", 1]:idx["delta", 2], 6] = 1
+		if(is.null(start.pars$delta)) pars[idx["delta", 1]:idx["delta", 2], 1] = 0 else pars[idx["delta", 1]:idx["delta", 2], 1] = start.pars$delta[1]
+		if(any(substr(fixed.names, 1, 5) == "delta")){
+			pars[idx["delta", 1]:idx["delta", 2], 1] = as.numeric(fixed.pars$delta)
+			pars[idx["delta", 1]:idx["delta", 2], 5] = as.numeric(fixed.pars$delta)
+			pars[idx["delta", 1]:idx["delta", 2], 6] = as.numeric(fixed.pars$delta)
+		}
+	}
+	if(modelinc[14]>0){
+		pars[idx["lambda", 1]:idx["lambda", 2], 5] = 0
+				pars[idx["lambda", 1]:idx["lambda", 2], 6] = 100
+				if(is.null(start.pars$lambda)) pars[idx["lambda", 1]:idx["lambda", 2], 1] = 0 else pars[idx["lambda", 1]:idx["lambda", 2], 1] = start.pars$lambda[1]
+		if(any(substr(fixed.names, 1, 6) == "lambda")){
+			pars[idx["lambda", 1]:idx["lambda", 2], 1] = as.numeric(fixed.pars$lambda)
+			pars[idx["lambda", 1]:idx["lambda", 2], 5] = as.numeric(fixed.pars$lambda)
+			pars[idx["lambda", 1]:idx["lambda", 2], 6] = as.numeric(fixed.pars$lambda)
+		}
+	}
+	if(modelinc[15]>0){
+		vxnames = paste("vxreg",1:modelinc[15],sep="")
+		pars[idx["vxreg", 1]:idx["vxreg", 2], 5] = 0
+		pars[idx["vxreg", 1]:idx["vxreg", 2], 6] = 100
+		pars[idx["vxreg", 1]:idx["vxreg", 2], 1] = rep(TinY, modelinc[15])
+		if(any(substr(start.names, 1, 5) == "vxreg")){
+			j = which(substr(start.names, 1, 5) == "vxreg")
+			vxmatch = charmatch(start.names[j],vxnames)
+			pars[vxnames[vxmatch], 1] = as.numeric(start.pars[j])
+		}
+		if(any(substr(fixed.names, 1, 5) == "vxreg")){
+			j = which(substr(fixed.names, 1, 5) == "vxreg")
+			vxmatch = charmatch(fixed.names[j],vxnames)
+			pars[vxnames[vxmatch], 1] = as.numeric(fixed.pars[j])
+			pars[vxnames[vxmatch], 5] = as.numeric(fixed.pars[j])
+			pars[vxnames[vxmatch], 6] = as.numeric(fixed.pars[j])
+		}
+	}
+	dbounds = .DistributionBounds(distribution = model$modeldesc$distribution)
+	if(modelinc[16]>0){
+		pars[idx["skew", 1]:idx["skew", 2], 5] = dbounds$skew.LB
+		pars[idx["skew", 1]:idx["skew", 2], 6] = dbounds$skew.UB
+		if(is.null(start.pars$skew)) pars[idx["skew", 1]:idx["skew", 2], 1] = dbounds$skew else pars[idx["skew", 1]:idx["skew", 2], 1] = start.pars$skew[1]
+		if(any(substr(fixed.names, 1, 4) == "skew")){
+			pars[idx["skew", 1]:idx["skew", 2], 1] = as.numeric(fixed.pars$skew)
+			pars[idx["skew", 1]:idx["skew", 2], 5] = as.numeric(fixed.pars$skew)
+			pars[idx["skew", 1]:idx["skew", 2], 6] = as.numeric(fixed.pars$skew)
+		}
+	}
+	if(modelinc[17]>0){
+		pars[idx["shape", 1]:idx["shape", 2], 5] = dbounds$shape.LB
+		pars[idx["shape", 1]:idx["shape", 2], 6] = dbounds$shape.UB
+		if(is.null(start.pars$shape)) pars[idx["shape", 1]:idx["shape", 2], 1] = dbounds$shape else pars[idx["shape", 1]:idx["shape", 2], 1] = start.pars$shape[1]
+		if(any(substr(fixed.names, 1, 5) == "shape")){
+			pars[idx["shape", 1]:idx["shape", 2], 1] = as.numeric(fixed.pars$shape)
+			pars[idx["shape", 1]:idx["shape", 2], 5] = as.numeric(fixed.pars$shape)
+			pars[idx["shape", 1]:idx["shape", 2], 6] = as.numeric(fixed.pars$shape)
+		}
+	}
+	if(modelinc[18]>0){
+		pars[idx["ghlambda", 1]:idx["ghlambda", 2], 5] = dbounds$ghlambda.LB
+		pars[idx["ghlambda", 1]:idx["ghlambda", 2], 6] = dbounds$ghlambda.UB
+		if(is.null(start.pars$ghlambda)) pars[idx["ghlambda", 1]:idx["ghlambda", 2], 1] = dbounds$ghlambda else pars[idx["ghlambda", 1]:idx["ghlambda", 2], 1] = start.pars$ghlambda[1]
+		if(any(substr(fixed.names, 1, 8) == "ghlambda")){
+			pars[idx["ghlambda", 1]:idx["ghlambda", 2], 1] = as.numeric(fixed.pars$ghlambda)
+			pars[idx["ghlambda", 1]:idx["ghlambda", 2], 5] = as.numeric(fixed.pars$ghlambda)
+			pars[idx["ghlambda", 1]:idx["ghlambda", 2], 6] = as.numeric(fixed.pars$ghlambda)
+		}
+	}
+	return( pars )
+}
 
 # Hentchel Family Model Initialization:
 # model specification
