@@ -1,14 +1,14 @@
 /*################################################################################
 ##
-##   R package rgarch by Alexios Ghalanos Copyright (C) 2009, 2010, 2011
-##   This file is part of the R package rgarch.
+##   R package rugarch by Alexios Ghalanos Copyright (C) 2009, 2010, 2011, 2012
+##   This file is part of the R package rugarch.
 ##
-##   The R package rgarch is free software: you can redistribute it and/or modify
+##   The R package rugarch is free software: you can redistribute it and/or modify
 ##   it under the terms of the GNU General Public License as published by
 ##   the Free Software Foundation, either version 3 of the License, or
 ##   (at your option) any later version.
 ##
-##   The R package rgarch is distributed in the hope that it will be useful,
+##   The R package rugarch is distributed in the hope that it will be useful,
 ##   but WITHOUT ANY WARRANTY; without even the implied warranty of
 ##   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ##   GNU General Public License for more details.
